@@ -8,6 +8,8 @@ from .inject_systematics import *
 from .inject_noise import *
 from .inject_spectrum import *
 from .fold import *
+from .flag_outliers import *
 from .compare import *
 from .remove_trends import *
 from .attach_model import *
+from .inflate_uncertainty import *
