@@ -51,7 +51,7 @@ def _warn_about_weird_binning(N, dimension, fraction_that_can_be_bad=0.0):
         allow many bins to come from the same data point, so you
         should expect weird correlations.
         """
-        warnings.warn(message)
+        cheerfully_suggest(message)
 
 
 def bin(
@@ -325,7 +325,7 @@ def bin_in_time(
 
         '''
         if k == "uncertainty":
-            warnings.warn(
+            cheerfully_suggest(
                 """
             Uncertainties and/or data quality flags might
             not be handled absolutely perfectly yet...
@@ -379,7 +379,7 @@ def bin_in_time(
         which data you think are usable, (c) change the `minimum_acceptable_ok`
         keyword for `.bin` to a smaller value, and/or (d) try larger bins.
         """
-        warnings.warn(message)
+        cheerfully_suggest(message)
         raise RuntimeError("No good data to bin! (see above)")
 
     # make sure dictionaries are on the up and up
@@ -509,6 +509,33 @@ def bin_in_wavelength(
     ):
         return self
 
+    if (
+        (self._is_probably_normalized() == False)
+        and (self.uncertainty is not None)
+        and np.any(self.uncertainty != 0)
+    ):
+
+        cheerfully_suggest(
+            f"""
+        It looks like you're trying to bin in wavelength for a
+        Rainbow object that might not be normalized. In the
+        current version of `chromatic`, binning before normalizing
+        might give inaccurate results if the typical uncertainty
+        varies strongly with wavelength.
+
+        Please consider normalizing first, for example with
+        `rainbow.normalize().bin(...)`
+        so that all uncertainties will effectively be relative,
+        and the inverse variance weighting used for binning
+        wavelengths together will give more reasonable answers.
+
+        If you really need to bin before normalizing, please submit
+        an Issue at github.com/zkbt/chromatic/, and we'll try to
+        prioritize implementing a statistically sound solution as
+        soon as possible!
+        """
+        )
+
     # set up binning parameters
     binkw = dict(weighting="inversevariance", drop_nans=False)
 
@@ -611,7 +638,7 @@ def bin_in_wavelength(
         which data you think are usable, (c) change the `minimum_acceptable_ok`
         keyword for `.bin` to a smaller value, and/or (d) try larger bins.
         """
-        warnings.warn(message)
+        cheerfully_suggest(message)
         raise RuntimeError("No good data to bin! (see above)")
 
     # make sure dictionaries are on the up and up
