@@ -78,11 +78,14 @@ def _is_probably_normalized(
     is_normalized = "normalize" in self.history()
 
     # are values generally close to 1?
-    spectrum = self.get_average_spectrum()
-    sigma = np.maximum(
-        u.Quantity(self.get_expected_uncertainty()).value,
-        u.Quantity(self.get_measured_scatter(method="MAD")).value,
-    )
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        spectrum = self.get_median_spectrum()
+
+        sigma = np.maximum(
+            u.Quantity(self.get_expected_uncertainty()).value,
+            u.Quantity(self.get_measured_scatter(method="MAD")).value,
+        )
     try:
         sigma_value = u.Quantity(sigma).value
         spectrum_value = u.Quantity(spectrum).value
