@@ -1,5 +1,7 @@
 from .spectral_resolution import *
 from .average_spectrum import *
+from .median_spectrum import *
 from .expected_uncertainty import *
 from .measured_scatter import *
+from .measured_scatter_in_bins import *
 from .subset import *
