@@ -39,7 +39,7 @@ def from_espinoza(rainbow, filepath):
 
     # populate a 1D array of times (with astropy units of time)
     times = np.arange(spectra.shape[0]) * u.minute
-    warnings.warn("The times are totally made up!")
+    cheerfully_suggest("The times are totally made up!")
     rainbow.timelike["time"] = times * 1
 
     # populate a 2D (row = wavelength, col = array of fluxes
