@@ -20,6 +20,8 @@ def plot_lightcurves(
     errorbarkw={},
     textkw={},
     filename=None,
+    scaling=1,
+    label_scatter=False,
     **kw,
 ):
     """
@@ -84,7 +86,7 @@ def plot_lightcurves(
         but this function doesn't know how to
         use them. Sorry!
         """
-        warnings.warn(message)
+        cheerfully_suggest(message)
 
     # make sure that the wavelength-based colormap is defined
     self._make_sure_cmap_is_defined(cmap=cmap, vmin=vmin, vmax=vmax)
@@ -92,6 +94,7 @@ def plot_lightcurves(
     w_unit, t_unit = u.Unit(w_unit), u.Unit(t_unit)
 
     min_time = np.nanmin(self.time.to_value(t_unit))
+    max_time = np.nanmax(self.time.to_value(t_unit))
 
     # make sure ax is set up
     if ax is None:
@@ -111,12 +114,12 @@ def plot_lightcurves(
     ax._most_recent_chromatic_plot_spacing = spacing
 
     # TO-DO: check if this Rainbow has been normalized
-    if self._is_probably_normalized():
+    if self._is_probably_normalized() or "model" in self.fluxlike:
         label_y = "1 - (0.5 + i) * spacing"
         ylim = 1 - np.array([self.nwave + 1, -1]) * spacing
     else:
         label_y = "np.median(plot_y) - 0.5 * spacing"
-        warnings.warn(
+        cheerfully_suggest(
             """
             It's not clear if/how this object has been normalized.
             Be aware that the baseline flux levels may therefore
@@ -125,6 +128,10 @@ def plot_lightcurves(
         ylim = None
     with quantity_support():
 
+        if label_scatter:
+            measured_rms = self.get_measured_scatter(quantity="residuals")
+            expected_rms = self.get_expected_uncertainty()
+
         #  loop through wavelengths
         for i, w in enumerate(self.wavelength):
 
@@ -138,8 +145,8 @@ def plot_lightcurves(
                 plot_x = t.to_value(t_unit)
 
                 # add an offset to this quantity
-                plot_y = -i * spacing + u.Quantity(y).value
-                plot_sigma = u.Quantity(sigma).value
+                plot_y = -i * spacing + (u.Quantity(y).value - 1) * scaling + 1
+                plot_sigma = u.Quantity(sigma).value * scaling
 
                 # get the color for this quantity
                 color = self.get_wavelength_color(w)
@@ -174,11 +181,25 @@ def plot_lightcurves(
                         **this_textkw,
                     )
 
+                if label_scatter is not False:
+                    this_textkw.update(ha="right")
+                    measured = measured_rms[i]
+                    expected = expected_rms[i]
+                    cadence = self.dt
+                    if text:
+                        plt.text(
+                            max_time,
+                            eval(label_y),
+                            eval(f'f"{label_scatter}"'),
+                            **this_textkw,
+                        )
+
         # add text labels to the plot
         plt.xlabel(f"{self._time_label} ({t_unit.to_string('latex_inline')})")
         plt.ylabel("Relative Flux (+ offsets)")
         if ylim is not None:
-            plt.ylim(*ylim)
+            if ylim[1] != ylim[0]:
+                plt.ylim(*ylim)
         plt.title(self.get("title"))
 
     if filename is not None:
