@@ -155,7 +155,7 @@ class PHOENIXLibrary:
         self._raw_wavelengths_url = "/".join(
             [self._raw_base_url, self._raw_wavelengths_filename]
         )
-        warnings.warn(
+        cheerfully_suggest(
             f"""
         Downloading (or finding locally) the shared wavelength grid from
         {self._raw_wavelengths_url}
@@ -174,7 +174,7 @@ class PHOENIXLibrary:
         ] = download_file_with_warning(
             self._raw_directory_url, pkgname=self._cache_label, cache=cache
         )
-        warnings.warn(
+        cheerfully_suggest(
             f"""
         Downloading (or finding locally) the index of files from
         {self._raw_directory_url}
@@ -198,7 +198,7 @@ class PHOENIXLibrary:
             for f in self._raw_spectrum_filenames
         ]
         N = len(self._raw_spectrum_urls)
-        warnings.warn(
+        cheerfully_suggest(
             f"""
         Downloading (or finding locally) {N} very large files from
         {self._raw_directory_url}
@@ -502,7 +502,7 @@ class PHOENIXLibrary:
         if np.any(ok):
             i = np.flatnonzero(ok)[0]
         else:
-            warnings.warn(
+            cheerfully_suggest(
                 f"""
             Your request resolution of R={R} is higher than the maximum.
             It will be rounded down to R={np.max(self._available_resolutions)}.
@@ -513,7 +513,7 @@ class PHOENIXLibrary:
         if i is not None:
             smallest_sufficient_R = self._available_resolutions[i]
         else:
-            warnings.warn(
+            cheerfully_suggest(
                 f"""
             Your requested resolution of R={R}
             is higher than the largest possible value
@@ -674,9 +674,7 @@ class PHOENIXLibrary:
 
         return (np.min(w), np.max(w), len(w))
 
-    def _get_average_spectrum_from_grid(
-        self, key, wavelength=None, wavelength_edges=None
-    ):
+    def _get_spectrum_from_grid(self, key, wavelength=None, wavelength_edges=None):
         if (wavelength is None) and (wavelength_edges is None):
             return self.models[key]
         else:
@@ -707,7 +705,7 @@ class PHOENIXLibrary:
                 )["y"]
                 return self.wavelength_cached_models[wavelength_key][key]
 
-    def get_average_spectrum(
+    def get_spectrum(
         self,
         temperature=5780,
         logg=4.43,
@@ -774,7 +772,9 @@ class PHOENIXLibrary:
                 elif wavelength_edges is None:
                     necessary_R = self._wavelengths_to_R(wavelength)
 
-                if self.metadata.get("R", 0) < necessary_R:
+                try:
+                    assert self.metadata.get("R", 0) >= necessary_R
+                except (AttributeError, AssertionError):
                     R = self._find_smallest_R(necessary_R)
                     assert False
 
@@ -794,6 +794,10 @@ class PHOENIXLibrary:
                         metallicity=m,
                     )
 
+        # strip units
+        if isinstance(temperature, u.Quantity):
+            temperature = temperature.value
+
         # store the inputs as a convenient dictionary to pass around
         inputs = dict(temperature=temperature, logg=logg, metallicity=metallicity)
 
@@ -818,7 +822,7 @@ class PHOENIXLibrary:
         if N == 1:
             weights = [1]
             key = (bounding_temperature[0], bounding_logg[0], bounding_metallicity[0])
-            spectrum = self._get_average_spectrum_from_grid(
+            spectrum = self._get_spectrum_from_grid(
                 key, wavelength=wavelength, wavelength_edges=wavelength_edges
             ).flatten()
         else:
@@ -837,13 +841,15 @@ class PHOENIXLibrary:
                         weights[i] = wt * wg * wz
                         key = (t, g, z)
                         try:
-                            this_log_spectrum = np.log(
-                                self._get_average_spectrum_from_grid(
-                                    key,
-                                    wavelength=wavelength,
-                                    wavelength_edges=wavelength_edges,
+                            with warnings.catch_warnings():
+                                warnings.simplefilter("ignore")
+                                this_log_spectrum = np.log(
+                                    self._get_spectrum_from_grid(
+                                        key,
+                                        wavelength=wavelength,
+                                        wavelength_edges=wavelength_edges,
+                                    )
                                 )
-                            )
                         except KeyError:
                             raise ValueError(
                                 f"""
@@ -872,7 +878,7 @@ class PHOENIXLibrary:
         if visualize:
             fi = plt.figure(figsize=(8, 3))
             for w, s in zip(weights, spectra):
-                plt.plot(wavelength, s, alpha=w)
+                plt.plot(wavelength, np.exp(s), alpha=w)
             plt.plot(wavelength, spectrum, color="black")
             plt.xlabel(
                 f"Wavelength ({self.units['wavelength'].to_string('latex_inline')})"
@@ -885,7 +891,19 @@ class PHOENIXLibrary:
         return wavelength, spectrum * self.units["spectrum"]
 
     def plot_available(self, temperature=None, logg=None, metallicity=None):
+        """
+        Make plots indicating the available grid points
+        in the loaded library of stellar spectra.
 
+        Parameters
+        ----------
+        temperature : float
+            Temperature, in K (with no astropy units attached).
+        logg : float
+            Surface gravity log10[g/(cm/s**2)] (with no astropy units attached).
+        metallicity : float
+            Metallicity log10[metals/solar] (with no astropy units attached).
+        """
         N = len(self._keys_for_indexing)
         fi, ax = plt.subplots(
             N, N, figsize=(8, 8), sharex="col", sharey="row", constrained_layout=True
@@ -910,12 +928,26 @@ class PHOENIXLibrary:
         plt.suptitle(f"R={self.metadata['R']}")
 
     def plot_time_required(self, iterations=5):
+        """
+        Run benchmarking tests to determine how long it takes
+        to perform different actions with the spectral library.
+
+        Parameters
+        ----------
+        iterations : int
+            How many times should we run each action?
+            (definitely do something more than 1, because
+            there are some overheads that behave differently
+            between the first time and subsequent times you
+            you generate a model spectrum)
+        """
         timings = {}
         for k in [
             "R",
             "load library",
             "get spectrum at grid point",
             "get interpolated spectrum",
+            "get interpolated spectrum at specific wavelengths",
         ]:
             timings[k] = []
 
@@ -931,26 +963,35 @@ class PHOENIXLibrary:
 
                 # how long does it take to retrieve a spectrum that exists?
                 start = get_current_seconds()
-                self.get_average_spectrum(temperature=3000, logg=4.5, metallicity=0.0)
+                self.get_spectrum(temperature=3000, logg=4.5, metallicity=0.0, R=R)
                 dt = get_current_seconds() - start
                 timings["get spectrum at grid point"].append(dt)
 
                 # how long does it take to retrieve a spectrum that needs to be interpolated?
                 start = get_current_seconds()
-                self.get_average_spectrum(temperature=3456, logg=5.67, metallicity=0.0)
+                self.get_spectrum(temperature=3456, logg=5.67, metallicity=0.0, R=R)
                 dt = get_current_seconds() - start
                 timings["get interpolated spectrum"].append(dt)
 
+                # how long does it take to retrieve a spectrum on a particular wavelength grid
+                wavelength = np.exp(np.arange(-1, 1, 1.01 / R)) * u.micron
+                start = get_current_seconds()
+                self.get_spectrum(
+                    temperature=3456, logg=5.67, metallicity=0.0, wavelength=wavelength
+                )
+                dt = get_current_seconds() - start
+                timings["get interpolated spectrum at specific wavelengths"].append(dt)
+
         t = Table(timings)
         plt.figure(figsize=(8, 4), dpi=300)
         for k in timings.keys():
             if k != "R":
                 plt.loglog(timings["R"], timings[k], marker="o", label=k, alpha=0.3)
         plt.legend(bbox_to_anchor=(1, 1), frameon=False)
-        plt.xlabel("R = $\lambda/\Delta\lambda$")
+        plt.xlabel(r"R = $\lambda/\Delta\lambda$")
         plt.ylabel("Time Required")
         return t
 
 
 phoenix_library = PHOENIXLibrary(photons=True)
-get_phoenix_photons = phoenix_library.get_average_spectrum
+get_phoenix_photons = phoenix_library.get_spectrum
